"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const backfill = __importStar(require("backfill/lib/api"));
const path_1 = __importDefault(require("path"));
const cacheConfig_1 = require("./cacheConfig");
const hashes = {};
const cacheHits = {};
exports.cacheHits = cacheHits;
async function computeHash(info, context) {
    const packagePath = path_1.default.dirname(info.packageJsonPath);
    const cacheConfig = cacheConfig_1.getCacheConfig(packagePath, context);
    const logger = backfill.makeLogger("warn", process.stdout, process.stderr);
    const name = info.name;
    logger.setName(name);
    const hash = await backfill.computeHash(packagePath, logger, context.command + context.args.join(" "), cacheConfig);
    hashes[info.name] = hash;
}
exports.computeHash = computeHash;
async function fetchBackfill(info, context) {
    const packagePath = path_1.default.dirname(info.packageJsonPath);
    const cacheConfig = cacheConfig_1.getCacheConfig(packagePath, context);
    const logger = backfill.makeLogger("warn", process.stdout, process.stderr);
    const hash = hashes[info.name];
    const cwd = path_1.default.dirname(packagePath);
    const cacheHit = await backfill.fetch(cwd, hash, logger, cacheConfig);
    cacheHits[info.name] = cacheHit;
}
exports.fetchBackfill = fetchBackfill;
async function putBackfill(info, context) {
    const packagePath = path_1.default.dirname(info.packageJsonPath);
    const cacheConfig = cacheConfig_1.getCacheConfig(packagePath, context);
    const logger = backfill.makeLogger("warn", process.stdout, process.stderr);
    const hash = hashes[info.name];
    const cwd = path_1.default.dirname(packagePath);
    try {
        await backfill.put(cwd, hash, logger, cacheConfig);
    }
    catch (e) {
        // here we swallow put errors because backfill will throw just because the output directories didn't exist
    }
}
exports.putBackfill = putBackfill;
